@@ -12,6 +12,7 @@ use Icinga\Application\Modules\Module;
 use Icinga\Data\ResourceFactory;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\NotFoundError;
+use Icinga\Forms\ActionForm;
 use Icinga\Forms\Config\GeneralConfigForm;
 use Icinga\Forms\Config\ResourceConfigForm;
 use Icinga\Forms\Config\UserBackendConfigForm;
@@ -81,6 +82,7 @@ class ConfigController extends Controller
         $form->handleRequest();
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('General');
         $this->createApplicationTabs()->activate('general');
     }
 
@@ -106,6 +108,7 @@ class ConfigController extends Controller
             ->order('name');
         $this->setupLimitControl();
         $this->setupPaginationControl($this->view->modules);
+        $this->view->title = $this->translate('Modules');
     }
 
     public function moduleAction()
@@ -122,7 +125,21 @@ class ConfigController extends Controller
                 $module = new Module($app, $name, $manager->getModuleDir($name));
             }
 
+            $toggleForm = new ActionForm();
+            $toggleForm->setDefaults(['identifier' => $name]);
+            if (! $this->view->moduleData->enabled) {
+                $toggleForm->setAction(Url::fromPath('config/moduleenable'));
+                $toggleForm->setDescription(sprintf($this->translate('Enable the %s module'), $name));
+            } elseif ($this->view->moduleData->loaded) {
+                $toggleForm->setAction(Url::fromPath('config/moduledisable'));
+                $toggleForm->setDescription(sprintf($this->translate('Disable the %s module'), $name));
+            } else {
+                $toggleForm = null;
+            }
+
             $this->view->module = $module;
+            $this->view->toggleForm = $toggleForm;
+            $this->view->title = $module->getName();
             $this->view->tabs = $module->getConfigTabs()->activate('info');
             $this->view->moduleGitCommitId = Version::getGitHead($module->getBaseDir());
         } else {
@@ -137,15 +154,20 @@ class ConfigController extends Controller
     public function moduleenableAction()
     {
         $this->assertPermission('config/modules');
-        $module = $this->getParam('name');
-        $manager = Icinga::app()->getModuleManager();
-        try {
-            $manager->enableModule($module);
+
+        $form = new ActionForm();
+        $form->setOnSuccess(function (ActionForm $form) {
+            $module = $form->getValue('identifier');
+            Icinga::app()->getModuleManager()->enableModule($module);
             Notification::success(sprintf($this->translate('Module "%s" enabled'), $module));
             $this->rerenderLayout()->reloadCss()->redirectNow('config/modules');
+        });
+
+        try {
+            $form->handleRequest();
         } catch (Exception $e) {
             $this->view->exceptionMessage = $e->getMessage();
-            $this->view->moduleName = $module;
+            $this->view->moduleName = $form->getValue('name');
             $this->view->action = 'enable';
             $this->render('module-configuration-error');
         }
@@ -157,15 +179,20 @@ class ConfigController extends Controller
     public function moduledisableAction()
     {
         $this->assertPermission('config/modules');
-        $module = $this->getParam('name');
-        $manager = Icinga::app()->getModuleManager();
-        try {
-            $manager->disableModule($module);
+
+        $form = new ActionForm();
+        $form->setOnSuccess(function (ActionForm $form) {
+            $module = $form->getValue('identifier');
+            Icinga::app()->getModuleManager()->disableModule($module);
             Notification::success(sprintf($this->translate('Module "%s" disabled'), $module));
             $this->rerenderLayout()->reloadCss()->redirectNow('config/modules');
+        });
+
+        try {
+            $form->handleRequest();
         } catch (Exception $e) {
             $this->view->exceptionMessage = $e->getMessage();
-            $this->view->moduleName = $module;
+            $this->view->moduleName = $form->getValue('name');
             $this->view->action = 'disable';
             $this->render('module-configuration-error');
         }
@@ -185,6 +212,7 @@ class ConfigController extends Controller
         $this->view->form = $form;
         $this->view->backendNames = Config::app('groups');
         $this->createApplicationTabs()->activate('authentication');
+        $this->view->title = $this->translate('Authentication');
         $this->render('userbackend/reorder');
     }
 
@@ -231,6 +259,7 @@ class ConfigController extends Controller
         });
         $form->handleRequest();
 
+        $this->view->title = $this->translate('Authentication');
         $this->renderForm($form, $this->translate('New User Backend'));
     }
 
@@ -269,6 +298,7 @@ class ConfigController extends Controller
             $this->httpNotFound(sprintf($this->translate('User backend "%s" not found'), $backendName));
         }
 
+        $this->view->title = $this->translate('Authentication');
         $this->renderForm($form, $this->translate('Update User Backend'));
     }
 
@@ -301,6 +331,7 @@ class ConfigController extends Controller
         });
         $form->handleRequest();
 
+        $this->view->title = $this->translate('Authentication');
         $this->renderForm($form, $this->translate('Remove User Backend'));
     }
 
@@ -314,6 +345,7 @@ class ConfigController extends Controller
             ->setKeyColumn('name')
             ->select()
             ->order('name');
+        $this->view->title = $this->translate('Resources');
         $this->createApplicationTabs()->activate('resource');
     }
 
@@ -334,6 +366,7 @@ class ConfigController extends Controller
         $form->handleRequest();
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('Resources');
         $this->render('resource/create');
     }
 
@@ -353,6 +386,7 @@ class ConfigController extends Controller
         $form->handleRequest();
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('Resources');
         $this->render('resource/modify');
     }
 
@@ -417,6 +451,7 @@ class ConfigController extends Controller
         }
 
         $this->view->form = $form;
+        $this->view->title = $this->translate('Resources');
         $this->render('resource/remove');
     }
 }
