@@ -52,7 +52,11 @@ class StaticController extends Controller
             return;
         }
 
-        $img = file_get_contents('http://www.gravatar.com/avatar/' . $filename . '?s=120&d=mm');
+        $img = @file_get_contents('http://www.gravatar.com/avatar/' . $filename . '?s=120&d=mm');
+        if ($img === false) {
+            $this->httpNotFound('Unable to connect to gravatar.com');
+        }
+
         $cache->store($cacheFile, $img);
         $response->setHeader('ETag', sprintf('"%s"', $cache->etagForCachedFile($cacheFile)));
 
@@ -64,16 +68,16 @@ class StaticController extends Controller
      */
     public function imgAction()
     {
-        $moduleRoot = Icinga::app()
+        $imgRoot = Icinga::app()
             ->getModuleManager()
             ->getModule($this->getParam('module_name'))
-            ->getBaseDir();
+            ->getBaseDir() . '/public/img/';
 
         $file = $this->getParam('file');
-        $filePath = realpath($moduleRoot . '/public/img/' . $file);
+        $filePath = realpath($imgRoot . $file);
 
-        if ($filePath === false) {
-            $this->httpNotFound('%s does not exist', $filePath);
+        if ($filePath === false || substr($filePath, 0, strlen($imgRoot)) !== $imgRoot) {
+            $this->httpNotFound('%s does not exist', $file);
         }
 
         if (preg_match('/\.([a-z]+)$/i', $file, $m)) {
